% Jerry Pratt
% March 31, 2000
% Plotting speed variation for PhD thesis with Flamingo...

load vel
load q_x
load q_z
load q_theta


figure(1)
grid on;
hold on;
plot(vel);
hold off;

%x_begin=input('enter x_begin  ')
%x_end = input('enter x_end  ')

x_begin = 250;
x_end = 1980;


t = zeros(x_end-x_begin+1,1);
v_nom = zeros(x_end-x_begin+1,1);
for(i=1:x_end-x_begin+1)
t(i) = (i-1)*0.02;
if (i>250) v_nom(i)=0.6; end;
end;

vel = vel(x_begin:x_end);
q_x = q_x(x_begin:x_end);
q_z = q_z(x_begin:x_end);
q_theta = q_theta(x_begin:x_end);