% Jerry Pratt
% March 31, 2000
% Plotting speed variation for PhD thesis with Flamingo...

figure(1);clf;
subplot(3,1,1)
plot(t,vel);hold on;
plot(t,v_nom,'--');
axis([0,35,0,1.0]);
ylabel('Velocity (m/s)');
subplot(3,1,2)
plot(t,q_z);
axis([0,35,0.8,0.9]);
ylabel('Height (m)');
subplot(3,1,3)
plot(t,q_theta);
axis([0,35,-0.2,0.2]);
ylabel('Pitch (rad)');
xlabel('Time (seconds)');

print -dill pushed.ai

